<?php

namespace Imgix;

class UrlBuilder {

	private $domains;
	private $useHttps;
	private $signKey;

	public function __construct( $domains, $useHttps = false, $signKey = "", $includeLibraryParam = true ) {
		if ( ! is_array( $domains ) ) {
			$this->domains = [ $domains ];
		} else {
			$this->domains = $domains;
		}

		if ( sizeof( $this->domains ) === 0 ) {
			throw new \InvalidArgumentException( "UrlBuilder requires at least one domain" );
		}

		$this->useHttps            = $useHttps;
		$this->signKey             = $signKey;
		$this->includeLibraryParam = $includeLibraryParam;
	}

	public function setSignKey( $key ) {
		$this->signKey = $key;
	}

	public function setUseHttps( $useHttps ) {
		$this->useHttps = $useHttps;
	}

	public function createURL( $path, $params = [] ) {
		$scheme = $this->useHttps ? "https" : "http";
		$domain = $this->domains[0];

		$uh = new UrlHelper( $domain, $path, $scheme, $this->signKey, $params );

		return $uh->getURL();
	}

	// force unsigned int since 32-bit systems can return a signed integer
	// see warning here: http://php.net/manual/en/function.crc32.php
	public static function unsigned_crc32( $v ) {
		return intval( sprintf( "%u", crc32( $v ) ) );
	}
}
