<?php
/*
displays upcoming event in a calendar layout

Input:
$events: array (... event object ...)
$atts: array (timezone, timeformat, calTitle, event_url, calendar_url, list_url)

*/

global $post, $eventbrite_music;
$settings = $eventbrite_music->get_options();

$events = ( ! empty( $events ) ) ? $events : [];
include( plugin_dir_path( __FILE__ ) . 'calendar_class.php' );
if ( isset( $events[ 0 ] ) ) {
	date_default_timezone_set( $events[ 0 ]->start->timezone );
}

if ( count( $events ) > 0 ) {
	$days         = [];
	$smallest_day = null;
	$largest_day  = null;

	extract( wp_parse_args( $atts, [
		'organizers'  => '',
		'venue'         => '',
		'timezone'      => '',
		'dateformat'    => 'D n/d',
		'caltitle'      => 'Upcoming Events',
		'calsync'       => 'off',
		'calshare'      => '',
		'exclude'       => '',
		'include'       => '',
		'num'           => '50',
		'linktarget'    => true,
		'imagesize'     => '',
		'featuredimage' => '',
		'excludevenue'  => '',
	] ) );

	$exclude = explode( ",", $exclude );
	$include = explode( ",", $include );
	?>

	<article class="calendar-view">
		<?php if ( ( 'on' === $calsync ) || ( 'true' === $calshare ) ) {
			?>
			<section class="calendar-sync cal-share">
				<button aria-label="Add this event to your Calendar" type="button"
						class="share-cal-button share-button eb-tooltip" data-target="calendar-modal">
					<i class="ico-calendar"></i><span class="button-text">Add To Calendar</span></button>
				<?php echo wp_kses_post( eb_calSyncMarkup( 'calendar', $event ) );
				?>
			</section>
		<?php }
		?>

		<?php if ( ! in_array( "calendar-list-flip", $exclude, true ) ) { ?>
			<section class="calendar-list-flip">
				<a href="<?php
				if ( isset( $post->eb_type ) ) {
					echo esc_url( eb_URL( $post->eb_type, $post->eb_id ) );
				} else {
					echo esc_url( eb_URL( 'listing' ) );
				} ?>">View List</a>
			</section>
		<?php } ?>

		<?php if ( ! in_array( "calendar-title", $exclude, true ) && ! in_array(
			"tfly-calendar-title",
			$exclude,
			true 
		) ) {
	?>
			<h1 class="calendar-title"><?php echo esc_html( $caltitle ); ?></h1>
			<?php
		}
		?>

		<?php

		foreach ( $events as $count => $event ) {
			date_default_timezone_set( $event->start->timezone );
			$event_date = date_create( $event->start->local );
			$key        = $event_date->format( "Y-m-d" );
			if ( ! isset( $days[ $key ][ strtotime( (string) $event->start->local ) ] ) ) {
				$days[ $key ][ strtotime( (string) $event->start->local ) ] = [];
			}
			$number_of_events_on_day = count( $days[ $key ][ strtotime( (string) $event->start->local ) ] );

			$days[ $key ][ strtotime( (string) $event->start->local ) ][ $number_of_events_on_day ] = $event;

			ksort( $days[ $key ] );
		}

		ksort( $days );

		$calendar = new Calendar();
		add_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html', 10, 2 );
		echo wp_kses_post( $calendar->show( $days, $atts, $settings, $post->post_name ) );
		remove_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html' );

		?>
	</article>
	<?php

} else {
	?>
	<article class="calendar-view">
		<h3 class="event-status-message"><?php eb_generate_no_events_status_message(); ?></h3>
	</article>
	<?php
}
