<?php
/*

displays upcoming event in a calendar layout

Input:
$events: array (... event object ...)
$atts: array (timezone, timeformat, calTitle, event_url, calendar_url, list_url)

*/

global $post, $eventbrite_music;
$settings = $eventbrite_music->get_options();
$events   = ( ! empty( $events ) ) ? $events : [];

if ( count( $events ) > 0 ) {
	$days         = [];
	$smallest_day = null;
	$largest_day  = null;

	extract( wp_parse_args( $atts, [
		'org'           => '',
		'venue'         => '',
		'timezone'      => '',
		'dateformat'    => 'D n/d', //'%a %-m/%d'
		'caltitle'      => 'Upcoming Events',
		'calsync'       => 'off',
		'calshare'      => '',
		'exclude'       => '',
		'include'       => '',
		'num'           => '50',
		'startofweek'   => 'Sunday',
		'startdate'     => '',
		'linktarget'    => true,
		'imagesize'     => 'medium1',
		'featuredimage' => '',
		'excludevenue'  => '',
	] ) );

	$exclude = explode( ",", $exclude );
	$include = explode( ",", $include );


	if ( $startofweek === 'Monday' ) {
		$dayNames = [ "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday" ];
	} else {
		$dayNames = [ "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" ];
	}

	if ( $startdate ) {
		$startDateObj = date_create( $startdate );
	}

	$e_index = 0;
	foreach ( $events as $count => $event ) {

		date_default_timezone_set( $event->start->timezone );

		$event_date = date_create( $event->start->local );
		$event_date->modify( "-" . ( $event_date->format( "G" ) ) . " hour" );
		$event_date->modify( "-" . ( $event_date->format( "i" ) ) . " minute" );

		if ( isset( $startDateObj ) && ( $event_date < $startDateObj ) ) {
			continue;
		}

		if ( $smallest_day === null || $event_date < $smallest_day ) {
			$smallest_day = $event_date;
		}

		if ( $largest_day === null || $event_date > $largest_day ) {
			$largest_day = $event_date;
		}

		$key = $event_date->format( "Y-m-d" );

		if ( ! isset( $days[ $key ][ $e_index ] ) ) {
			$days[ $key ][ $e_index ] = [];
		}

		$number_of_events_on_day = count( $days[ $key ][ $e_index ] );

		$days[ $key ][ $e_index ][ $number_of_events_on_day ] = $event;
		$e_index ++;

	}

	ksort( $days );

	if ( $smallest_day === $largest_day ) {
		$largest_day = clone $largest_day;
	}

}

if ( count( $events ) > 0 ) {

	$cur_month = false;
	$start     = true;
	$today     = date_create(); ?>

	<article class="calendar-view">

		<?php if ( ( 'on' === $calsync ) || ( 'true' === $calshare ) ) {
			?>
			<section class="calendar-sync cal-share">
				<button aria-label="Add this event to your Calendar" type="button"
						class="share-cal-button share-button eb-tooltip" data-target="calendar-modal">
					<i class="ico-calendar"></i><span class="button-text">Add To Calendar</span></button>
				<?php echo wp_kses_post( eb_calSyncMarkup( 'calendar', $event ) );
				?>
			</section>
		<?php } // end calshare

		if ( ! in_array( "calendar-list-flip", $exclude, true ) ) { ?>
			<section class="calendar-list-flip">
				<a href="<?php
				if ( isset( $post->eb_type ) ) {
					echo esc_url( eb_URL( $post->eb_type, $post->eb_id ) );
				} else {
					echo esc_url( eb_URL( 'listing' ) );
				} ?>">View List</a>
			</section>
		<?php } ?>

		<?php if ( ! in_array( "calendar-title", $exclude, true ) && ! in_array(
			"tfly-calendar-title",
			$exclude,
			true 
		) ) {
	if ( isset( $post->eb_type ) ) {
		// Listing is for a venue detail page
		if ( isset( $events->venue ) && ( 'venue' === $post->eb_type ) ) {
			$caltitle = $events->venue->name . ' - Events';
			// Listng is for a org (promoter) detail page
		} elseif ( isset( $events->primary_organizer->name ) && ( 'org' === $post->eb_type ) ) {
			$caltitle = $events->primary_organizer->name . ' - Events';
		}
	}
	if ( isset( $caltitle ) ) { ?>
				<h1 class="calendar-title"><?php echo esc_html( $caltitle ); ?></h1>
				<?php
	}
		} ?>

		<table>
			<tr>
				<?php $ii = 0;
				for ( $event_date = $smallest_day; strtotime( $event_date->format( "Y-m-d" ) ) <= strtotime( $largest_day->format( "Y-m-d" ) ); $event_date->modify( "+1 day" ) ) {

					if ( $startofweek === 'Monday' ) {
						$day_of_week = $event_date->format( "N" ) - 1;
					} else {
						$day_of_week = $event_date->format( "w" );
					}
					$month = $event_date->format( "F" );
					if ( $cur_month !== $month ) {
						if ( ! $start && absint( $day_of_week ) !== 0 ) {

							$x = $day_of_week;
							while ( $x < 7 ) {
								echo '<td class="data ' . esc_html( $dayNames[ $x ] ) . '">&nbsp;</td>';
								$x ++;
							}
						}

						$start = false;

						if ( $cur_month !== false ) {
							echo '</tr></table><table><tr>';
						}

						$new_cal = true;

						$cur_month = $month;
						if ( ! in_array( "month-title", $exclude, true ) ) {
							echo '<td colspan="7"><h3 class="month">' . esc_html( $cur_month ) . '</h3></td>';
						}
						echo '</tr><tr>';
					}

					if ( absint( $day_of_week ) === 0 ) {
						echo '</tr><tr>';
						$new_cal = false;
					}

					if ( $new_cal ) {
						for ( $x = 0; $x < $day_of_week; $x ++ ) {
							echo '<td class="data ' . esc_attr( $dayNames[ $x ] ) . '">&nbsp;</td>';
						}
						$new_cal = false;
					}

					echo '<td class="data ' . esc_attr( $dayNames[ $day_of_week ] );
					if ( $today->format( 'Y-m-d' ) === $event_date->format( 'Y-m-d' ) ) {
						echo " today";
					}
					echo ' vevent has-event">';
					echo '<section class="date dtstart"><span class="value-title" title="' . esc_attr( $event_date->format( 'c' ) ) . '"></span>' . esc_html( eb_eventDate(
						$dateformat,
						strtotime( $event_date->format( 'Y-m-d' ) ) 
					) ) . '</section>';

					$date_str = $event_date->format( "Y-m-d" );

					if ( isset( $days[ $date_str ] ) ) {
						foreach ( $days[ $date_str ] as $day => $event_list ) {
							$num_events = count( $event_list );
							for ( $counter = 0; $counter < $num_events; $counter ++ ) {
								$ii ++;
								$event = $event_list[ $counter ];
								//If the hide end date or hide state date we're just going to hide the event
								//in the calendar as it doesn't make sense to show it in a date if it's not being shown.
								if ( $event->hide_start_date ) {
									continue;
								}
								$calClass = "one-event";
								if ( $num_events === $counter + 1 ) {
									// last event box has less padding
									$calClass = "one-event last-event";
								}

								$urlVars       = eb_getInitialUrlVars( $event );
								$templPath     = eb_locate_template( '/calendar-item' );
								$templateClass = 'calendar';
								$data_values   = eb_locate_template( '/event-data-values' );
								if ( ! empty( $data_values ) ) {
									require $data_values;
								}
								$performers         = new Performers();
								$performancesMarkup = $performers->build_Calendar_Performers(
									$event,
									$edpUrl,
									$exclude 
								);
								if ( ! empty( $templPath ) ) {
									require $templPath;
								}
								$urlVars = null;
								add_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html', 10, 2 );
								echo wp_kses_post( $markup );
								remove_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html' );
							}

						}
					}
					echo '</td>';
				}

				while ( $day_of_week < 6 ) { ?>
					<td class="data">&nbsp;</td>
					<?php $day_of_week ++;

				}
				?>
			</tr>
		</table>
	</article>
	<?php

	echo '<!-- api#';
	if ( ( count( $events ) > 0 ) ) {
		echo absint( count( $events ) );
	}
	if ( isset( $ii ) ) {
		echo esc_html( ' cal# ' . $ii );
	}
	echo '-->';

} else {
	?>
	<div class="calendar-view">
		<h3 class="event-status-message"><?php eb_generate_no_events_status_message(); ?></h3>
	</div>
	<?php
}
