<?php

//TODO: Should be tested for php errors and undefined variables when working.
class Calendar {

	/********************* PROPERTY ********************/
	private $currentYear = 0;
	private $currentMonth = 0;
	private $currentDay = 0;
	private $currentDate = null;
	private $daysInMonth = 0;
	private $naviHref = null;
	/********************* PUBLIC **********************/

	/**
	 ** Constructor
	 **/
	public function __construct() {
		$this->naviHref = isset( $_SERVER[ 'PHP_SELF' ] ) ? sanitize_text_field( $_SERVER[ 'PHP_SELF' ] ) : '';
	}

	/**
	 ** Print out the calendar
	 **/
	public function show( $days, $atts, $settings, $postName ) {
		$year  = isset( $_GET[ 'calyear' ] ) ? sanitize_text_field( $_GET[ 'calyear' ] ) : null;
		$month = isset( $_GET[ 'calmonth' ] ) ? sanitize_text_field( $_GET[ 'calmonth' ] ) : null;

		if ( null === $year || empty( $year ) || ! is_numeric( $year ) ) {
			$year = date( "Y", time() );
		}

		if ( null === $month || empty( $month ) || ! is_numeric( $month ) ) {
			$month = date( "m", time() );
		}

		$this->currentYear  = $year;
		$this->currentMonth = $month;
		$this->daysInMonth  = $this->_daysInMonth( $month, $year );
		$this->currentDate  = DateTimeImmutable::createFromFormat(
			'Y-m-d',
			$this->currentYear . '-' . $this->currentMonth . '-1' 
		);

		$content = '<div class="calendar-content">' . PHP_EOL
				   . '<div class="calendar-header">' . PHP_EOL . $this->_createNavi( $postName ) . PHP_EOL
				   . '</div>' . PHP_EOL
				   . '<div class="calendar-clear"></div>' . PHP_EOL
				   . '<div class="calendar-grid">' . PHP_EOL;

		$weeksInMonth = $this->_weeksInMonth( $month, $year );
		// Create weeks in a month
		for ( $i = 0; $i < $weeksInMonth; $i ++ ) {
			// Create days in a week
			for ( $j = 0; $j <= 7; $j ++ ) {
				$content .= $this->_showDay( ( $i * 7 + $j ), $atts, $days, $settings );
			}
		}
		$content .= '</div>' . PHP_EOL;
		$content .= '<div class="calendar-clear"></div>' . PHP_EOL;
		$content .= '</div>' . PHP_EOL;

		return $content;
	}

	/********************* PRIVATE **********************/
	/**
	 ** Create the calendar days
	 **/
	private function _showDay( $cellNumber, $atts, $days, $settings ) {
		if ( intval( $this->currentDay ) === 0 ) {
			$firstDayOfTheWeek = date( 'N', strtotime( $this->currentYear . '-' . $this->currentMonth . '-01' ) );
			if ( intval( $firstDayOfTheWeek ) === 7 ) {
				$cellNumber = $cellNumber + 7;
			}
			if ( intval( $cellNumber ) === intval( $firstDayOfTheWeek ) ) {
				$this->currentDay = 1;
			}
		}
		if ( ( $this->currentDay !== 0 ) && ( $this->currentDay <= $this->daysInMonth ) ) {
			$this->currentDate = date(
				'Y-m-d',
				strtotime( $this->currentYear . '-' . $this->currentMonth . '-' . $this->currentDay ) 
			);
			$cellDate          = date( $atts[ 'dateformat' ], strtotime( $this->currentDate ) );
			$this->currentDay ++;
		} else {
			$this->currentDate = null;
			$cellDate          = null;
		}
		$today_day = date( "d" );
		$today_mon = date( "m" );
		$today_yea = date( "Y" );

		$class_day = ( $cellDate === $today_day && $this->currentMonth === $today_mon && $this->currentYear === $today_yea ? 'data today' : 'data' );
		$hasEvent  = ( isset( $days[ $this->currentDate ] ) ) ? ' has-event' : '';
		$eventData = ( isset( $days[ $this->currentDate ] ) ) ? $this->_buildEventData(
			$days[ $this->currentDate ],
			$atts,
			$settings 
		) : '';

		return '<section class="' . esc_attr( $class_day . $hasEvent ) . '"><section class="date dtstart"><span class="value-title" title="'
			   . date(
				   'c',
				   strtotime( $this->currentDate ) 
			   ) . '"></span>' . esc_html( $cellDate ) . '</section>' . wp_kses_post( $eventData ) . '</section>' . PHP_EOL;
	}

	/**
	 ** Create event data
	 **/
	private function _buildEventData( $eventData, $atts, $settings ) {
		$linktarget = isset( $atts[ 'linktarget' ] ) ? $atts[ 'linktarget' ] : '';
		$imagesize  = isset( $atts[ 'imagesize' ] ) ? $atts[ 'imagesize' ] : '';
		$exclude    = isset( $atts[ 'exclude' ] ) ? explode( ",", $atts[ 'exclude' ] ) : [];
		$include    = isset( $atts[ 'include' ] ) ? explode( ",", $atts[ 'include' ] ) : [];
		$totalMarkup = '';
		foreach ( $eventData as $event_list ) {
			$num_events = count( $event_list );
			for ( $counter = 0; $counter < $num_events; $counter ++ ) {
				$event = $event_list[ $counter ];
				//If the hide end date or hide state date we're just going to hide the event
				//in the calendar as it doesn't make sense to show it in a date if it's not being shown.
				if ( $event->hide_start_date ) {
					continue;
				}
				$calClass = "one-event";
				if ( $num_events === $counter + 1 ) {
					// last event box has less padding
					$calClass = "one-event last-event";
				}
				$urlVars       = eb_getInitialUrlVars( $event );
				$templPath     = eb_locate_template( '/calendar-item' );
				$templateClass = 'calendar';
				$data_values   = eb_locate_template( '/event-data-values' );
				if ( ! empty( $data_values ) ) {
					require $data_values;
				}
				$performers         = new Performers();
				$performancesMarkup = $performers->build_Calendar_Performers( $event, $edpUrl, $exclude );

				if ( ! empty( $templPath ) ) {
					require $templPath;
				}
				$urlVars     = null;
				$totalMarkup .= $markup;
			}
		}

		return $totalMarkup;
	}

	/**
	 ** Create navigation
	 **/
	private function _createNavi( $postName ) {

		$nextDate     = $this->currentDate->add( new DateInterval( 'P1M' ) );
		$previousDate = $this->currentDate->sub( new DateInterval( 'P1M' ) );

		$previousUrl = $this->_generateNavigationLink( $postName, $previousDate );
		$nextUrl     = $this->_generateNavigationLink( $postName, $nextDate );

		return
			'<a class="calendar_prev" href="' . $previousUrl . '">Prev</a>' . PHP_EOL
			. '<span class="calendar-title">' . PHP_EOL
			. '<span class="month">' . esc_html( $this->currentDate->format( 'F' ) ) . ' </span>' . PHP_EOL
			. '<span class="year">' . esc_html( $this->currentDate->format( 'Y' ) ) . '</span>' . PHP_EOL
			. '</span>' . PHP_EOL
			. '<a class="calendar_next" href="' . $nextUrl . '">Next</a>';
	}

	private function _generateNavigationLink( $postName, $date ) {
		return esc_url(
			sprintf(
				'?pagename=%s&amp;calmonth=%02d&amp;calyear=%d',
				$postName,
				$date->format( 'm' ),
				$date->format( 'Y' )
			)
		);
	}

	/**
	 ** Calculate number of weeks in a particular month
	 **/
	private function _weeksInMonth( $month = null, $year = null ) {
		if ( null === $year ) {
			$year = date( "Y", time() );
		}
		if ( null === $month ) {
			$month = date( "m", time() );
		}
		// Find number of days in this month
		$daysInMonths   = $this->_daysInMonth( $month, $year );
		$numOfweeks     = ( ( ( $daysInMonths % 7 ) === 0 ) ? 0 : 1 ) + intval( $daysInMonths / 7 );
		$monthEndingDay = date( 'N', strtotime( $year . '-' . $month . '-' . $daysInMonths ) );
		$monthStartDay  = date( 'N', strtotime( $year . '-' . $month . '-01' ) );
		if ( $monthEndingDay < $monthStartDay ) {
			$numOfweeks ++;
		}

		return $numOfweeks;
	}

	/**
	 ** Calculate number of days in a particular month
	 **/
	private function _daysInMonth( $month = null, $year = null ) {
		if ( null === ( $year ) ) {
			$year = date( "Y", time() );
		}
		if ( null === ( $month ) ) {
			$month = date( "m", time() );
		}

		return date( 't', strtotime( $year . '-' . $month . '-01' ) );
	}
}
