jQuery.noConflict();

jQuery(document).ready(function ($) {
    var events = [];
    var datesToEvents = {};
    var monthNames = "January February March April May June July August September October November December".split(" ");


    function onMonthChanged(year, month) {
        displayLoading(true);

        var fromDate = year + "-" + zeroPad(month) + "-01";
        var thruDate = year + "-" + zeroPad(month) + "-" + zeroPad(lastDayOfMonth(month, year));

        handler = function (response) {

                response = jQuery.parseJSON(response);
                populateCalendarWithEvents(response.data, month - 1);
                $("#eventDateHeader").hide();
                $("#shows").empty();
                findFirstDayOfMonthElementWithEventsOnCalendar(year, month).click();
                displayLoading(false);
                $(document).trigger('dpMonthLoaded'); // trigger event
        };

        jQuery.ajax({
            type: 'GET',
            url: ajax_object.ajax_url,
            async: true,
            data: {
                action: 'eb-mobile-cal-ajax',
                eb_nonce: ajax_object.eb_nonce,
                venueId: venueId,
                orgId: orgId,
                fromDate: fromDate,
                thruDate: thruDate,
                embedModal: embedModal,
                exclude: excludeOptions
            },
            success: handler
        });
    }

    $("#datepicker").datepicker({
        inline: true,
        nextText: '>>',
        prevText: '<<',
        dateFormat: 'yy-mm-dd',
        onSelect: onDateSelected,
        onChangeMonthYear: onMonthChanged,
        beforeShow: function (input, inst) {
            console.log("before show");
        }
    });

    var d = new Date();
    var curr_year = d.getFullYear();
    var curr_month = d.getMonth() + 1;
    onMonthChanged(curr_year, curr_month);
    year = '';
    month = '';

    var embedModal = window.embedModal;

    function onDateSelected(dateText) {
        $("#shows").empty();

        $(document).trigger('dpDateSelected'); // trigger event

        var eventDate = dateFromCalendarDateString(dateText);
        var eventsForDate = datesToEvents[eventDate];
        var eventsForDateCount = eventsForDate ? eventsForDate.length : 0;

        $("#eventDateHeader").text(
            (eventsForDateCount > 0 ? eventsForDateCount + " e" : "No e") + "vent" + (eventsForDateCount === 1 ? "" : "s") + " for " +
            monthNames[eventDate.getMonth()] + " " + eventDate.getDate() + ", " + eventDate.getFullYear()).show();

        if (eventsForDate) {
            $.each(eventsForDate, function (i, event) {
                $("#shows").append(createEventListItem(event));
                if (embedModal) {
                    var eventID = parseInt(event.id);
                    return createEmbeddedModal(eventID);
                }
            });
        }

        setTimeout(function () {
            populateCalendarWithEvents(events);
        }, 10);
    }

    function scrollTo(selector) {
        $("html:not(:animated), body:not(:animated)").animate({scrollTop: selector.offset().top}, "slow");
    }

    function createEventListItem(event) {
        return event['markup'];
    }

    function createEmbeddedModal(eventID) {
        if( typeof ga === 'undefined') {
            return;
        }

        ga(function (tracker) {
            var clientId = tracker.get('clientId');

            window.EBWidgets.createWidget({
                widgetType: "checkout",
                eventId: eventID,
                modal: true,
                googleAnalyticsClientId: clientId,
                modalTriggerElementId: "eventbrite-widget-modal-trigger-" + eventID,
                affiliateCode: affiliateCode,
            });
        });
    }

    function findDayOfMonthElementOnCalendar(day) {
        var element = $([]);

        $("#datepicker tbody td a").each(function (i, a) {
            if (day.toString(10) == $.trim($(a).text())) {
                element = $(a);
                return false;
            }
        });

        return element;
    }

    function findFirstDayOfMonthElementWithEventsOnCalendar(year, month) {
        var d = new Date();
        var curr_year = d.getFullYear();
        var curr_month = d.getMonth();

        if (year === '' || ((year === curr_year) && ((month - 1) === curr_month))) {
            //return $("#datepicker .ui-datepicker-today:first");
            return findDayOfMonthElementOnCalendar(new Date().getDate());
        } else {
            return $("#datepicker .eventsExist:first");
        }
    }

    function populateCalendarWithEvents(newEvents, curr_month) {
        events = newEvents;
        datesToEvents = {};
        if ('undefined' === typeof curr_month) {
            curr_month_name = $('.ui-datepicker-month').text();
            curr_month = new Date(Date.parse(curr_month_name + " 1, 2012")).getMonth();
        }

        $.each(events, function (i, event) {
            // Ex: 2010-08-01 12:00:00
            var year = parseInt(event.start.local.substring(0, 4), 10);
            var month = parseInt(event.start.local.substring(5, 7), 10) - 1;
            var day = parseInt(event.start.local.substring(8, 10), 10);
            var start_date = new Date(year, month, day, 0, 0, 0, 0);
            var eventsForThisDate = datesToEvents[start_date];

            if (curr_month === month) {
                if (!eventsForThisDate) {
                    eventsForThisDate = [];
                    datesToEvents[start_date] = eventsForThisDate;
                }

                eventsForThisDate.push(event);
            }
        });

        $("#datepicker .eventsExist").removeClass("eventsExist");

        $.each(datesToEvents, function (dateAsString) {
            findDayOfMonthElementOnCalendar(new Date(dateAsString).getDate()).addClass("eventsExist");
        });
    }

    // Ex: 2010-11-07
    function dateFromCalendarDateString(dateAsString) {
        var year = parseInt(dateAsString.substring(0, 4), 10);
        var month = parseInt(dateAsString.substring(5, 7), 10) - 1;
        var day = parseInt(dateAsString.substring(8, 10), 10);
        return new Date(year, month, day, 0, 0, 0, 0);
    }

    // Month is 0-indexed
    function lastDayOfMonth(month, year) {
        return new Date(year, month, 0).getDate();
    }

    function zeroPad(value) {
        return value < 10 ? "0" + value : value;
    }

    function displayLoading(display) {
        if (display) {
            $(".calendar-wrapper > *").not("#loadingMessage").hide();
            $("#loadingMessage").show();
        } else {
            $("#loadingMessage").hide();
            $(".calendar-wrapper > *").not("#loadingMessage").show();
        }
    }
});