<?php
/**
 * gold-parent_s functions and definitions
 *
 * @package gold-parent_s
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'gold_parent_s_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function gold_parent_s_setup() {

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Assign as the main menu in the header', 'gold-parent_s' ),
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'image', 'video', 'link' ) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'gold_parent_s_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
	) );
}
endif; // gold_parent_s_setup
add_action( 'after_setup_theme', 'gold_parent_s_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function gold_parent_s_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Main Widgets', 'gold-parent_s' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'gold_parent_s_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function gold_parent_s_scripts() {
	wp_enqueue_style( 'gold-site-child-style', get_stylesheet_uri() );
	wp_enqueue_script( 'gold-parent_s-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'gold-parent_s-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'gold_parent_s_scripts' );

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
// require get_template_directory() . '/inc/jetpack.php';


// Removing Customizer Options for Gold Parent
if ( ! function_exists( 'child_customizer_settings' ) ) {
	function remove_customizer_settings( $wp_customize ) {
		$wp_customize->remove_setting( 'header_textcolor' );
		$wp_customize->remove_section( 'blogname' );
		$wp_customize->remove_section( 'blogdescription' );
		$wp_customize->remove_section( 'static_front_page' );
		$wp_customize->remove_section( 'title_tagline' );
		$wp_customize->remove_section( 'themes' );
		$wp_customize->remove_section( 'colors' );
		$wp_customize->remove_section( 'background_image' );
	}
}
add_action( 'customize_register', 'remove_customizer_settings', 20 );


// Rebuilding Customizer Options for Gold Parent
function gold_customize_register( $wp_customize ) {
	// Mobile options
	$wp_customize->add_section( 'mobile_options', array(
		'title' => __( 'Mobile Customization' ),
		'priority' => 200
	) );
	$wp_customize->add_setting( 'mobile_customizer_image', array(
		'capability'           => 'edit_theme_options',
		'sanitize_callback' => ''
	) );
	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'mobile_customizer_image', array(
		'label'   => 'Header Image',
		'description' => __( 'Mobile header images must be 364px X 88px or smaller.' ),
		'section' => 'mobile_options',
		'flex_width'  => true,
		'flex_height' => false,
		'width'       => 364,
		'height'      => 88
	) ) );
	$wp_customize->add_setting( 'mobile_customizer_css', array(
		'default'        => '',
		'capability'           => 'edit_theme_options',
		'sanitize_callback'    => 'wp_filter_nohtml_kses',
		'sanitize_js_callback' => 'wp_filter_nohtml_kses'
	) );
	$wp_customize->add_control( 'mobile_customizer_css', array(
		'type'    => 'textarea',
		'label'   => 'Custom CSS',
		'section' => 'mobile_options'
	) );
}
add_action('customize_register','gold_customize_register');

/**
 * Adds Blog ID to the array of body classes.
 */
function contractor_body_class( $classes ) {
	$classes[] = 'site-id-' . get_current_blog_id();
	return $classes;
}
add_filter( 'body_class', 'contractor_body_class' );


/* keep galleries, press links and FAQs out of the blog */
function be_exclude_post_formats_from_blog( $query ) {
	if( $query->is_main_query() && $query->is_home() ) {
		$tax_query = array( array(
			'taxonomy' => 'post_format',
			'field' => 'slug',
			'terms' => array( 'post-format-gallery','post-format-aside','post-format-link' ),
			'operator' => 'NOT IN',
		) );
		$query->set( 'tax_query', $tax_query );
	}
}
add_action( 'pre_get_posts', 'be_exclude_post_formats_from_blog' );

/* featured image support */
add_theme_support('post-thumbnails');

if ( ! function_exists ( 'post_thumbnail_child' ) ) {
	function post_thumbnail() {
		set_post_thumbnail_size(150, 150, true); // Standard post thumbnails
	}
}

if ( ! function_exists ( 'gallery_thumb_child' ) ) {
	function gallery_thumb() {
		add_image_size('gallery-format-thumbnail',110,85,true); // WP gallery template post thumbnails
	}
	add_action( 'wp_loaded', 'gallery_thumb', 15 );
}

if ( ! function_exists ( 'gallery_link_child' ) ) {
	function gallery_link() {
		add_image_size('gallery-link-imgsize',800,800,false); // WP gallery linked image size
	}
	add_action( 'wp_loaded', 'gallery_link', 15 );
}

// pulling new image size in gallery shortcode
function wp_gallery_attachment_link_filter( $content, $post_id, $size, $permalink ) {
	if (! $permalink) {
		$image = wp_get_attachment_image_src( $post_id, 'gallery-link-imgsize' );
		$new_content = preg_replace('/href=\'(.*?)\'/', 'href=\'' . $image[0] . '\'', $content );
		return $new_content;
	} else {
		return $content;
	}
}
add_filter('wp_get_attachment_link', 'wp_gallery_attachment_link_filter', 10, 4);